Photo Import
============

Application to import photos from one directory into a hierarchical directory
structure in another directory based on the EXIF data of the photos.

Tests
-----
To run the test suite locally, use `pytest`:

```bash
➜ pip install -r requirements.txt
➜ pytest
```
